@@ -6,11 +6,9 @@ from reqif.cli.cli_arg_parser import AnonimizeCommandConfig
 from reqif.models.reqif_spec_object import ReqIFSpecObject, SpecObjectAttribute
 from reqif.models.reqif_specification import ReqIFSpecification
 from reqif.models.reqif_types import SpecObjectAttributeType
-
 from reqif.parser import ReqIFParser
 from reqif.unparser import ReqIFUnparser
 
-
 ANONYMIZED = "...Anonymized..."
 
 
@@ -21,14 +19,16 @@ class AnonymizeCommand:
         if not os.path.isfile(input_file):
             sys.stdout.flush()
             message = "error: passthrough command's input file does not exist"
-            print(f"{message}: {input_file}")
+            print(f"{message}: {input_file}")  # noqa: T201
             sys.exit(1)
 
         output = AnonymizeCommand._anonymize(config)
         output_file = config.output_file
         output_dir = os.path.dirname(output_file)
         if not os.path.isdir(output_dir):
-            print(f"error: output directory does not exist: {output_file}")
+            print(  # noqa: T201
+                f"error: output directory does not exist: {output_file}"
+            )
             sys.exit(1)
         with open(output_file, "w", encoding="UTF-8") as file:
             file.write(output)
